@@ -5,6 +5,7 @@ import (
 
 	"github.com/mitchellh/mapstructure"
 
+	"github.com/anchore/grype/grype/db/v5/pkg/qualifier/platformcpe"
 	"github.com/anchore/grype/grype/db/v5/pkg/qualifier/rpmmodularity"
 	"github.com/anchore/grype/internal/log"
 )
@@ -34,6 +35,13 @@ func FromJSON(data []byte) ([]Qualifier, error) {
 				continue
 			}
 			qualifiers = append(qualifiers, q)
+		case "platform-cpe":
+			var q platformcpe.Qualifier
+			if err := mapstructure.Decode(r, &q); err != nil {
+				log.Warn("Error decoding platform-cpe package qualifier:  (%v)", err)
+				continue
+			}
+			qualifiers = append(qualifiers, q)
 		default:
 			log.Warn("Skipping unsupported package qualifier: %s", k)
 			continue
