@@ -1,7 +1,6 @@
 package pkg
 
 import (
-	"errors"
 	"os"
 	"strings"
 	"testing"
@@ -15,12 +14,6 @@ import (
 	"github.com/anchore/syft/syft/source"
 )
 
-func assertAs(expected string) assert.ErrorAssertionFunc {
-	return func(t assert.TestingT, err error, i ...interface{}) bool {
-		return assert.ErrorContains(t, errors.New(expected), err.Error())
-	}
-}
-
 func TestParseSyftJSON(t *testing.T) {
 	tests := []struct {
 		Fixture  string
@@ -150,7 +143,7 @@ func TestParseSyftJSON(t *testing.T) {
 
 			for _, d := range deep.Equal(test.Packages, pkgs) {
 				if strings.Contains(d, ".ID: ") {
-					// today ID's get assigned by the catalog, which will change in the future. But in the meantime
+					// today ID's get assigned by the collection, which will change in the future. But in the meantime
 					// that means that these IDs are random and should not be counted as a difference we care about in
 					// this test.
 					continue
